summaryrefslogtreecommitdiff
path: root/gr-digital/include
diff options
context:
space:
mode:
Diffstat (limited to 'gr-digital/include')
-rw-r--r--gr-digital/include/digital/CMakeLists.txt3
-rw-r--r--gr-digital/include/digital/additive_scrambler_bb.h1
-rw-r--r--gr-digital/include/digital/binary_slicer_fb.h (renamed from gr-digital/include/digital_binary_slicer_fb.h)50
-rw-r--r--gr-digital/include/digital_bytes_to_syms.h62
-rw-r--r--gr-digital/include/digital_constellation.h2
5 files changed, 28 insertions, 90 deletions
diff --git a/gr-digital/include/digital/CMakeLists.txt b/gr-digital/include/digital/CMakeLists.txt
index c6384ecd6e..8eb5eef883 100644
--- a/gr-digital/include/digital/CMakeLists.txt
+++ b/gr-digital/include/digital/CMakeLists.txt
@@ -79,8 +79,7 @@ install(FILES
# impl_glfsr.h
# impl_mpsk_snr_est.h
additive_scrambler_bb.h
-# binary_slicer_fb.h
-# bytes_to_syms.h
+ binary_slicer_fb.h
# clock_recovery_mm_cc.h
# clock_recovery_mm_ff.h
# cma_equalizer_cc.h
diff --git a/gr-digital/include/digital/additive_scrambler_bb.h b/gr-digital/include/digital/additive_scrambler_bb.h
index b7322f6a0b..b5689b2744 100644
--- a/gr-digital/include/digital/additive_scrambler_bb.h
+++ b/gr-digital/include/digital/additive_scrambler_bb.h
@@ -70,5 +70,4 @@ namespace gr {
} /* namespace digital */
} /* namespace gr */
-
#endif /* INCLUDED_DIGITAL_ADDITIVE_SCRAMBLER_BB_H */
diff --git a/gr-digital/include/digital_bytes_to_syms.h b/gr-digital/include/digital_bytes_to_syms.h
deleted file mode 100644
index c1857c8cf2..0000000000
--- a/gr-digital/include/digital_bytes_to_syms.h
+++ /dev/null
@@ -1,62 +0,0 @@
-/* -*- c++ -*- */
-/*
- * Copyright 2004,2012 Free Software Foundation, Inc.
- *
- * This file is part of GNU Radio
- *
- * GNU Radio is free software; you can redistribute it and/or modify
- * it under the terms of the GNU General Public License as published by
- * the Free Software Foundation; either version 3, or (at your option)
- * any later version.
- *
- * GNU Radio is distributed in the hope that it will be useful,
- * but WITHOUT ANY WARRANTY; without even the implied warranty of
- * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
- * GNU General Public License for more details.
- *
- * You should have received a copy of the GNU General Public License
- * along with GNU Radio; see the file COPYING. If not, write to
- * the Free Software Foundation, Inc., 51 Franklin Street,
- * Boston, MA 02110-1301, USA.
- */
-#ifndef INCLUDED_GR_BYTES_TO_SYMS_H
-#define INCLUDED_GR_BYTES_TO_SYMS_H
-
-#include <digital_api.h>
-#include <gr_sync_interpolator.h>
-
-class digital_bytes_to_syms;
-typedef boost::shared_ptr<digital_bytes_to_syms> digital_bytes_to_syms_sptr;
-
-DIGITAL_API digital_bytes_to_syms_sptr digital_make_bytes_to_syms();
-
-/*!
- * \brief Convert stream of bytes to stream of +/- 1 symbols
- * \ingroup converter_blk
- *
- * input: stream of bytes; output: stream of float
- *
- * This block is deprecated.
- *
- * The combination of gr_packed_to_unpacked_bb followed by
- * digital_chunks_to_symbols_bf or digital_chunks_to_symbols_bc handles the
- * general case of mapping from a stream of bytes into arbitrary float
- * or complex symbols.
- *
- * \sa gr_packed_to_unpacked_bb, gr_unpacked_to_packed_bb,
- * \sa digital_chunks_to_symbols_bf, digital_chunks_to_symbols_bc.
- */
-class DIGITAL_API digital_bytes_to_syms : public gr_sync_interpolator
-{
- friend DIGITAL_API digital_bytes_to_syms_sptr
- digital_make_bytes_to_syms();
-
- digital_bytes_to_syms();
-
- public:
- int work (int noutput_items,
- gr_vector_const_void_star &input_items,
- gr_vector_void_star &output_items);
-};
-
-#endif /* INCLUDED_GR_BYTES_TO_SYMS_H */
diff --git a/gr-digital/include/digital_constellation.h b/gr-digital/include/digital_constellation.h
index a72bfb74c5..0e0c817d7a 100644
--- a/gr-digital/include/digital_constellation.h
+++ b/gr-digital/include/digital_constellation.h
@@ -23,7 +23,7 @@
#ifndef INCLUDED_DIGITAL_CONSTELLATION_H
#define INCLUDED_DIGITAL_CONSTELLATION_H
-#include <digital_api.h>
+#include <digital/api.h>
#include <vector>
#include <math.h>
#include <gr_complex.h>
diff --git a/gr-digital/include/digital_binary_slicer_fb.h b/gr-digital/include/digital/binary_slicer_fb.h
index 35a7380fb9..7a3a1e9a0a 100644
--- a/gr-digital/include/digital_binary_slicer_fb.h
+++ b/gr-digital/include/digital/binary_slicer_fb.h
@@ -1,6 +1,6 @@
/* -*- c++ -*- */
/*
- * Copyright 2006,2011 Free Software Foundation, Inc.
+ * Copyright 2006,2011,2012 Free Software Foundation, Inc.
*
* This file is part of GNU Radio
*
@@ -23,31 +23,33 @@
#ifndef INCLUDED_DIGITAL_BINARY_SLICER_FB_H
#define INCLUDED_DIGITAL_BINARY_SLICER_FB_H
-#include <digital_api.h>
+#include <digital/api.h>
#include <gr_sync_block.h>
-class digital_binary_slicer_fb;
-typedef boost::shared_ptr<digital_binary_slicer_fb> digital_binary_slicer_fb_sptr;
+namespace gr {
+ namespace digital {
+
+ /*!
+ * \brief slice float binary symbol outputting 1 bit output
+ * \ingroup converter_blk
+ * \ingroup digital
+ *
+ * x < 0 --> 0
+ * x >= 0 --> 1
+ */
+ class DIGITAL_API binary_slicer_fb : virtual public gr_sync_block
+ {
+ public:
+ // gr::digital::binary_slicer_fb::sptr
+ typedef boost::shared_ptr<binary_slicer_fb> sptr;
-DIGITAL_API digital_binary_slicer_fb_sptr digital_make_binary_slicer_fb ();
+ /*!
+ * \brief Make binary symbol slicer block.
+ */
+ sptr make();
+ };
-/*!
- * \brief slice float binary symbol outputting 1 bit output
- * \ingroup converter_blk
- * \ingroup digital
- *
- * x < 0 --> 0
- * x >= 0 --> 1
- */
-class DIGITAL_API digital_binary_slicer_fb : public gr_sync_block
-{
- friend DIGITAL_API digital_binary_slicer_fb_sptr digital_make_binary_slicer_fb ();
- digital_binary_slicer_fb ();
-
- public:
- int work (int noutput_items,
- gr_vector_const_void_star &input_items,
- gr_vector_void_star &output_items);
-};
+ } /* namespace digital */
+} /* namespace gr */
-#endif
+#endif /* INCLUDED_DIGITAL_BINARY_SLICER_FB_H */